#
# spec file for package publicsuffix
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 yaneti@declera.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           publicsuffix
Version:        20190205
Release:        1.1
Summary:        Cross-vendor public domain suffix database
License:        MPL-2.0
Group:          Productivity/Networking/Other
URL:            https://publicsuffix.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  psl-make-dafsa
BuildArch:      noarch

%description
The Public Suffix List is a cross-vendor initiative to provide
an accurate list of domain name suffixes, maintained by the hard work
of Mozilla volunteers and by submissions from registries.
Software using the Public Suffix List will be able to determine where
cookies may and may not be set, protecting the user from being
tracked across sites.

%prep
%setup -q

%build
psl-make-dafsa \
    --input-format=psl \
    --output-format=binary \
    public_suffix_list.dat public_suffix_list.dafsa

%check
make %{?_smp_mflags} test-syntax

%install
install -m 644 -p -D public_suffix_list.dat \
  %{buildroot}/%{_datadir}/%{name}/public_suffix_list.dat
ln -s public_suffix_list.dat %{buildroot}/%{_datadir}/%{name}/effective_tld_names.dat
install -m 644 -p -D public_suffix_list.dafsa \
  %{buildroot}/%{_datadir}/%{name}/public_suffix_list.dafsa

%files
%license LICENSE
%{_datadir}/%{name}

%changelog
* Mon Feb 18 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190205:
  * Add domains of Individual Network Berlin e.V. (#711)
  * Added bss.design to PSL (#685)
  * Add fastly-terrarium.com (#729)
  * Add Swisscom Application Cloud domains (#698)
  * Update public_suffix_list.dat with api.stdlib.com (#751)
  * Add regional domain for filegear.me (#713)
  * Remove bv.nl (#758)
  * Update public_suffix_list.dat
* Tue Feb 12 2019 Fridrich Strba <fstrba@suse.com>
- Link public_suffix_list.dat to effective_tld_names.dat for the
  purpose of httpcomponents-client
* Fri Jan 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in full python3, psl-make-dafsa already pulls in
  what it needs to generate the things
* Sat Jan  5 2019 astieger@suse.com
- Update to version 20181227:
  * Add run.app and a.run.app to the psl (#681)
  * Add telebit.io .app .xyz (#726)
  * Add Leadpages domains (#731)
  * Add public suffix entries for dapps.earth (#708)
  * Add Bytemark Hosting domains (#620)
  * Remove .STATOIL
  * linter: Expect rules to be in NFKC (#725)
  * Convert list data from NFKD to NFKC (#720)
  * Update LS (#718)
* Tue Oct 30 2018 astieger@suse.com
- Update to version 20181030:
  * Add readthedocs.io (#722)
  * Remove trailing whitespace from L11948 (#721)
  * Add krasnik.pl, leczna.pl, lubartow.pl, lublin.pl, poniatowa.pl
    and swidnik.pl domains to the Public Suffix List (#670)
  * Add instantcloud.cn by Redstar Consultants (#696)
  * Add Fermax and mydobiss.com domain (#706)
  * Add shop.th & online.th (#716)
  * Add siteleaf.net (#655)
  * Add wpcomstaging.com and go-vip.co to the PSL (#719)
* Mon Oct 15 2018 astieger@suse.com
- Update to version 20181003:
  * Remove deleted TLDs (#710)
  * Added apigee.io (#712)
  * Add AWS ElasticBeanstalk Ningxia, CN region (#597)
  * Add Github PULL REQUEST TEMPLATE (#699)
  * Add ong.br 2nd level domain (#707)
* Wed Aug 15 2018 astieger@suse.com
- Update to version 20180813:
  * Update .ID list (#703)
  * Updated .bn ccTLD. Removed wildcard. (#702)
  * Remove stackspace.space from PSL (#691)
  * Remove XPERIA (#697)
* Tue Jul 24 2018 astieger@suse.com
- Update to version 20180719:
  * Remove .IWC
  * Update Kuwait's ccTLD (.kw)
  * htts://www.transip.nl => https://www.transip.nl
  * Remove MEO and SAPO
* Tue May 29 2018 astieger@suse.com
- Update to version 20180523:
  * Remove 1password domains (#632)
  * Add cleverapps.io (Clever Cloud) (#634)
  * Remove .BOOTS
  * Add azurecontainer.io to Microsoft domains (#637)
  * Change the patchnewgtlds tool for the updated .zw domain
  * Add new gTLDs up to 2018-04-17 and new ccTLDs up to 2018-04-17
  * cloud.muni.cz cloud subdomains (#622)
  * Add YunoHost DynDns domains: nohost.me & noho.st (#615)
  * Use a custom token for the newGTLD list (#645)
  * lug.org.uk (#514)
  * Adding xnbay.com,u2.xnbay.com,u2-local.xnbay.com to public_suffix_list.dat. (#506)
  * Adding customer.speedpartner.de (#585)
  * Adding ravendb.net subdomains (#535)
  * Adding own.pm (#544)
  * pcloud.host (#531)
  * Add additional Lukanet Ltd domains (#652)
  * Add zone.id (#575)
  * Add half.host (#571)
  * Update 香港 TLD (#568)
  * Add Now-DNS domains (#560)
  * Added blackbaudcdn.net private domain to PSL (#558)
  * Adding IServ GmbH domains (#552)
  * Add FASTVPS EESTI OU domains (#541)
  * nic.it - update regions and provinces (#524)
  * Update Futureweb OG Private Domains (#520)
  * add United Gameserver virtualuser domains (#600)
  * Add Lightmaker Property Manager, Inc domains (#604)
  * Update Uberspace domains (#616)
  * Add Datto, Inc domains
  * Add memset hosting domains (#625)
  * Add utwente.io (#626)
  * Add bci.dnstrace.pro (#630)
  * Add May First domains (#635)
  * Add Linki Tools domains (#636)
  * Update NymNom domains
  * Add Co & Co domains (#650)
  * Add new gTLDs up to 2018-05-08 (#653)
  * Correct linter issues (#654)
  * Add cnpy.gdn as private domain (#633)
  * Add freedesktop.org (#619)
  * Add Omnibond Systems (#656)
  * Add hasura.app to the list (#668)
  * Update gu ccTLD suffixes (#669)
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 20180328:
  * Add gwiddle.co.uk (#521)
  * Add ox.rs (#522)
  * Add myjino.ru (#512)
  * Add ras.ru domains (#511)
  * Add AWS ElasticBeanstalk Osaka, JP region (#628)
  * Remove trailing whitespace (#621)
* Tue Mar 13 2018 astieger@suse.com
- Update to version 20180312:
  * Add Cloudeity customer subdomains
  * Removed se.com
  * .br updated - one new city domain barueri.br
- use %%license (bsc#1082318)
* Wed Feb 28 2018 astieger@suse.com
- Update to version 20180223:
  * Add mozilla-iot.org (#605)
* Tue Feb 20 2018 astieger@suse.com
- update to 20180218:
  * Add YesCourse private entry for official.academy
  * Add schokokeks.net
  * Add 2038.io
  * Adding cloud66.ws customer domain for Cloud66
  * Add linkyard.cloud
* Fri Jan 26 2018 astieger@suse.com
- Update to version 20180125:
  * .br updated - 12 new 2nd level city domains
  * Update .ke suffixes to include second-level domains
  * Remove myfusion.cloud domain
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 20171228:
  * Add Paris region (#579)
  * Fixed alwaysdata.net. (#555)
  * Add Combell domains (#565)
  * Adding scrysec.com (#528)
  * Add Fedora Openshift app domains (#533)
  * Add resin.io device domains to list (#499)
  * Add nh-serv.co.uk to list file (#491)
  * Add 1Password domains (#562)
  * Add s5y.io (#572)
  * Add social domains - NIC.bo (#467)
* Tue Nov  7 2017 astieger@suse.com
- Update to version 20171028:
  * remove .htc TLD (#548)
  * Delete "REMOVED" TLDs (#536)
  * .br updated - 19 new 2nd level city domains (#546)
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 20170910:
  * Add pixolino.com domain (#456)
  * Add Fancy Bits domains to the PSL (#495)
  * Update AWS Elastic Beanstalk domains. (#484)
  * Add domreg.merit.edu registry (#293)
  * Update WeDeploy/Liferay domains. (#510)
  * Add v-info.info (#508)
  * Add debian.net (#516)
  * .br updated - 18 new 2nd level city domains (#507)
* Fri Aug 18 2017 astieger@suse.com
- Update to version 20170809:
  * Update Futureweb OG Private Domains (#498)
  * Add byen.site (#490)
* Thu Jul 20 2017 astieger@suse.com
- Update to version 20170713:
  * Add newly delegated ICANN ccTLDs based on 2017-07-10 database (#483)
  * Add boomla.net domain (#476)
  * Add Dynu.com domain names to the PSL (#447)
  * Add Netlify domains (#469)
  * add Nodeart domains (#471)
  * Add additional evennode.com domains (#481)
  * Add LiquidNet domains (#452)
  * Add NymNom domains (#425)
  * Add Sub 6 Limited domains (#462)
  * Pull request for adding org.ru, net.ru and pp.ru names (#412)
* Mon Jul  3 2017 astieger@suse.com
- Update to version 20170622:
  * .br updated 2nd level domains + 3rd level gov.br (#464)
  * Adding WeDeploy domains (#420)
  * Add nodum.io aPaas (#431)
  * Add Filegear domain (#434)
  * Add Lukanet Ltd domains (#439)
  * Add metacentrum.cz cloud subdomains (#438)
  * Add flynnhosting.net for Flynn (#459)
  * Add lima-city/TrafficPlex domains (#454)
  * Add mytuleap.com domain (#453)
  * Add lcube-server.de, svn-repos.de, git-repos.de (#455)
  * Added Thingdusts per-user subdomains. (#419)
  * Update XS4ALL domains (#457)
  * Add CloudAccess.net domains (#466)
  * Add info.cx (#460)
  * Add DrayDNS domains (#475)
  * Update GitHub domains
* Mon Jun 12 2017 astieger@suse.com
- Update to version 20170608:
  * Add nom.nc (#305)
  * Add definima domain suffix (#383)
  * Sort by company
  * Delete .ORIENTEXPRESS (#437)
  * Add cloud.goog (#449)
* Tue May  9 2017 astieger@suse.com
- Update to version 20170424:
  * Additional evennode.com domains (#428)
  * Update .zw extensions (#369)
  * Add Ici la Lune hosting domain (#370)
  * Update Daplie, Inc domains (#388)
  * Add XS4ALL Internet bv domains (#397)
  * Add Octopodal Solutions, LLC domains (#404)
  * Add Cloud66 domains (#409)
  * Add A.W. AdvisorWebsites.com Software Inc domains (#413)
  * Add Fedora domains (#414)
  * Add Synology, Inc. domains (#415)
  * Correct Fedora domain sorting
  * Adding IPiFony Systems, Inc. domains (#429)
  * Add Uberspace domains (#432)
  * Add SensioLabs, SAS domains (#423)
  * Update .ar ccTLD (#406)
  * Update .ไทย domains (#408)
  * Add Qutheory, LLC domains (#407)
  * Adding Quip domains (#427)
  * Add eDirect Corp domains (#398)
  * Add bplaced network domains (#433)
  * Add Mail.ru Group domains (#421)
  * Update Platform.sh / Commerce Guys SAS domains (#417)
  * Formatting
* Tue Apr  4 2017 tchvatal@suse.com
- Update to version 20170331:
  * Include fastly.net subdomain for related services (#424)
* Thu Mar 16 2017 astieger@suse.com
- Update to version 20170303:
  * Add new gTLDs up to 2017-02-23 (#405)
  * adding storj.farm for Storj Labs Inc. (#400)
* Fri Feb 10 2017 astieger@suse.com
- Update to version 20170206:
  * Add additional private Fastly domains (#371)
  * Add onion (#386)
  * Removing s3.amazonaws.com wildcard, adding AWS eu-west-2 regional endpoints (#387)
  * Add .RU and .SU geographic suffixes owned by FAITID (#384)
* Sat Jan 14 2017 mpluskal@suse.com
- Update to version 20170105:
  * Add Amune.org to Public Suffix List (#357)
  * Adding TwoDNS TLD's to public_suffix_list.dat (#328)
  * Remove ro.com from Public Suffix List (#346)
  * Add 1gb.ua domains (#353)
  * Add homeoffice.gov.uk (#342)
  * Update list of .RU reserved domains (#359)
  * Add remotewd.com for Western Digital
- Enable syntax checks
* Wed Dec 14 2016 astieger@suse.com
- Update to version 20161211:
  * Remove volgograd.ru from Public Suffix List (#340)
  * Add user.party.eus to PRIVATE section (#348)
  * Adding wildcard for *.s3.amazonaws.com, ca-central-1 AWS region and changing Amazon contact info (#351)
  * Added on-web.fr (Planet-Work shared hosting) (#349)
  * Added .ni as a valid user registerable domain. (#336)
  * Sort .NI
* Sat Dec  3 2016 mpluskal@suse.com
- Update to version 20161128:
  * Update Futureweb OG Private Domains (#332)
  * DynamicDNS and Portmapping Service Feste-IP.net (#295)
  * Added Enonic Cloud domains to list (#330)
  * Added dynamic domains for Yombo (#331)
  * Update Amazon AWS domains (#259)
  * Merge new gTLDs up through 2016-11-29 (#341)
- Use _service for easier updating
* Tue Nov 22 2016 astieger@suse.com
- build compact DAFSA format of the list
* Mon Nov 14 2016 astieger@suse.com
- 2016-11-10 update:
  * Add sinacloud domains: appchizi.com, applinzi.com
  * Add apps.lair.io and stolos.io
  * Add ddnss.org domains
  * Update .JP suffix
  * Add Securepoint Dynamic DNS domains
  * Add now.sh
  * Add shiftedit.io
* Mon Oct 24 2016 astieger@suse.com
- 2016-10-21 update:
  * Update .mz suffixes according to registry
  * Add Futureweb OG Private Domains
  * Add alwaysdata.net
  * Add publishproxy.com
  * Add TAIFUN Software AG domains
  * Add Revitalised Limited domains
  * Add opencraft.hosting
  * Add KnightPoint Systems domain
  * Brazilian .leg.br
  * Add Keyweb AG domains
  * Add ClouDNS domains
  * Add TransIP domains
  * Add .cy suffix
  * Add myfusion.cloud
* Tue Aug 30 2016 astieger@suse.com
- 2016-08-26 update:
  * update .krd
  * Add js.org
  * Move lib.de.us to private section
  * Add wmflabs.orgf
  * Add new gTLSs up to 2016-08-17
  * Add bnr.la
  * Add Joyent Triton
  * Add protonet.io
* Mon Aug  8 2016 astieger@suse.com
- 2016-08-05 update:
  * Add myasustor.com
  * Add myqnapcloud domains
* Mon Aug  1 2016 astieger@suse.com
- 2016-07-31 update:
  * Add meteorapp.com
  * Add Drud domains
  * Add backplaneapp.io
  * Add gitlab.io
  * Add static.land
  * Add stackspace.space
  * Add browsersafetymark.io
* Mon Jul  4 2016 astieger@suse.com
- 2016-07-03 update:
  * Add mycd.eu
  * Add beep.pl
  * Add hepforge.org
  * Add certmgr.org
  * Add fhapp.xyz
  * Update .jp suffixes
  * Add tuxfamily.com
  * Add evennode.com
  * Add realm.cz
  * Add logoip.de, logoip.com
  * Add virtueldomein.nl
  * Add *.magnetosite.cloud
  * Add cyryptonomic.net
  * Correct Amazon AWS EC2 China
  * Add hasura-app.io.
  * Update .BA suffixes
* Fri Jun 10 2016 astieger@suse.com
- 2016-06-10 update:
  * Add spacekit.io
  * Add potager.org domains
  * Add boxfuse.io
* Fri May 27 2016 astieger@suse.com
- 2016-05-25 update:
  * Add No-IP.com's domains
  * Add pgfog.com
  * Add Freebox domains
  * Add e4.cz
  * Add skyhat.io
  * Add dy.fi, tunk.org
  * Update .jp
* Tue May 10 2016 astieger@suse.com
- 2016-05-09 update:
  * Add new gTLDs up to 2016-05-09
  * Add dnshome.de
* Fri Apr 22 2016 astieger@suse.com
- 2016-04-20 update:
  * Add ownprovider.com for OwnProvider
  * Add nerdpol.ovh part of nsupdate.info dyndns service
  * Add townnews customer domain suffixes
  * Add on-aptible.com
  * Add router.management
  * Add compute.estate and alces.network
  * Update .zm TLD
  * Add GoIP DNS Services
  * Add chirurgiens-dentistes-en-france.fr
  * Add myfritz.net for AVM
  * Add nsupdate.info dyndns service
  * Add dedyn.io
  * Google: Add *.0emm.com
  * Add daplie.me
  * Add hzc.io
  * Add new gTLDs up to 2016-04-04
* Thu Mar 31 2016 idonmez@suse.com
- 2016-03-15 update:
  * add .xn--e1a4c, oy.lc
  * add new gTLDs through 2016-03-25
* Sat Mar 12 2016 astieger@suse.com
- 2016-03-10 update:
  * add co.dk, biz.dk, firm.dk, store.dk, reg.dk
  * add cyon.link and cyon.site
  * remove patheon.io, add patheonsite.io
* Sun Mar  6 2016 astieger@suse.com
- 2016-03-02 update:
  * add apps.fbsbx.com
  * update github list
  * add new gTLDs up through 2016-03-01
* Fri Feb 19 2016 astieger@suse.com
- 2016-02-19 update:
  * Add xenapponazure.com to the PSL
  * Add dynv6 dynamic DNS service
  * Add new .pro suffixes
  * Update AWS domains
* Tue Feb  2 2016 psimons@suse.com
- 2016-02-02 update:
  * add *.i.ng
  * update ng reference URL
  * sort entries alphabetically
* Fri Jan 29 2016 astieger@suse.com
- 2016-01-29 update:
  * Add Drobo Dynamic DNS service
  * add TLD .co.cz
  * Minor change for .rs and .срб (xn--90a3ac) domains
  * Add prgmr.com customer domain suffix
* Thu Jan 21 2016 astieger@suse.com
- 2016-01-15 update:
  * Clean-up some inconsistency of data
  * Add additional entries to .GY ccTLD
  * Remove .TP, TLD has been decommissioned
  * Renamed agrica.za to agric.za
* Thu Jan  7 2016 astieger@suse.com
- 2016-01-06 update:
  * Add cloudfunctions.net to Google, Inc. section
  * Add new gTLDs up to 2016-01-04
* Mon Dec  7 2015 astieger@suse.com
- update to 20151205
* Tue Dec  1 2015 astieger@suse.com
- update to 20151130:
  * Remove .an domains from the list (deleted from root zone).
  * Update .ni to have explicit list.
  * Remove taxi.aero, marketplace.aero
* Sun Nov 15 2015 astieger@suse.com
- initial package for openSUSE / SLE based on Fedora spec
- update to 20151112
